FadingScroll class
Add a fading effect to a scrollable child.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FadingScroll
Constructors
- FadingScroll({Key? key, required FadingScrollWidgetBuilder builder, ScrollController? controller, double? startFadingSize, double? endFadingSize, double? fadingSize, double? startScrollExtent, double? endScrollExtent, double? scrollExtent, Duration? transitionDuration})
-
const
Properties
- builder → FadingScrollWidgetBuilder
-
A builder for the scrollable child that will have the fading mask applied.
final
- controller → ScrollController?
-
The scroll controller that is used to track the scrolling status.
final
- endFadingSize → double?
-
The fading mask maximum size when there is content hidden after the
end of the current scroll position.
final
- endScrollExtent → double?
-
The minimum amount of scroll needed before which the fading mask has
its endFadingSize full size.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startFadingSize → double?
-
The fading mask maximum size when there is content hidden before the
start of the current scroll position.
final
- startScrollExtent → double?
-
The minimum amount of scroll needed after which the fading mask has
its startFadingSize full size.
final
- transitionDuration → Duration?
-
The duration for animate the mask whenever it changes.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FadingScroll> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultScrollExtent → const double
- The default value if neither startScrollExtent nor endScrollExtent is provided to a FadingScroll.