builder property
A builder for the scrollable child that will have the fading mask applied.
Implementation
final FadingScrollWidgetBuilder builder;
A builder for the scrollable child that will have the fading mask applied.
final FadingScrollWidgetBuilder builder;