controller property

ScrollController? controller
final

The scroll controller that is used to track the scrolling status.

If not provided, one is created internally and given to the builder.

Implementation

final ScrollController? controller;