endFadingSize property
The fading mask maximum size when there is content hidden after the end of the current scroll position.
If not provided, it is equivalent to endScrollExtent.
Implementation
final double? endFadingSize;
The fading mask maximum size when there is content hidden after the end of the current scroll position.
If not provided, it is equivalent to endScrollExtent.
final double? endFadingSize;