startScrollExtent property
The minimum amount of scroll needed after which the fading mask has its startFadingSize full size.
Implementation
final double? startScrollExtent;
The minimum amount of scroll needed after which the fading mask has its startFadingSize full size.
final double? startScrollExtent;