transitionDuration property
The duration for animate the mask whenever it changes.
If null, the transition isn't animated.
Implementation
final Duration? transitionDuration;
The duration for animate the mask whenever it changes.
If null, the transition isn't animated.
final Duration? transitionDuration;