ConnectAction enum
Values
- getSchema → const ConnectAction
-
const ConnectAction('ext.isar.getSchema') - listInstances → const ConnectAction
-
const ConnectAction('ext.isar.listInstances') - watchInstance → const ConnectAction
-
const ConnectAction('ext.isar.watchInstance') - executeQuery → const ConnectAction
-
const ConnectAction('ext.isar.executeQuery') - removeQuery → const ConnectAction
-
const ConnectAction('ext.isar.removeQuery') - importJson → const ConnectAction
-
const ConnectAction('ext.isar.importJson') - exportJson → const ConnectAction
-
const ConnectAction('ext.isar.exportJson') - editProperty → const ConnectAction
-
const ConnectAction('ext.isar.editProperty')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- method → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ConnectAction> - A constant List of the values in this enum, in order of their declaration.