ConnectQuery class

Constructors

ConnectQuery({required String instance, required String collection, FilterOperation? filter, int? offset, int? limit, String? sortProperty, bool? sortAsc})
ConnectQuery.fromJson(Map<String, dynamic> json)
factory

Properties

collection String
final
filter → FilterOperation?
final
hashCode int
The hash code for this object.
no setterinherited
instance String
final
limit int?
final
offset int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortAsc bool?
final
sortProperty String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toQuery() → Query
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited