controller property
The scroll controller that is used to track the scrolling status.
If not provided, one is created internally and given to the builder.
Implementation
final ScrollController? controller;
The scroll controller that is used to track the scrolling status.
If not provided, one is created internally and given to the builder.
final ScrollController? controller;