startFadingSize property
The fading mask maximum size when there is content hidden before the start of the current scroll position.
If not provided, it is equivalent to startScrollExtent. And if neither startScrollExtent nor endScrollExtent is provided then its value is defaultScrollExtent.
Implementation
final double? startFadingSize;