ConnectClient class
Constructors
- ConnectClient(VmService vmService, String isolateId)
Properties
-
collectionInfo
→ Map<
String, ConnectCollectionInfo> -
final
-
collectionInfoChanged
→ Stream<
void> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instancesChanged
→ Stream<
void> -
no setter
- isolateId → String
-
final
-
queryChanged
→ Stream<
void> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vmService → VmService
-
final
Methods
-
disconnect(
) → Future< void> -
editProperty(
ConnectEdit edit) → Future< void> -
executeQuery(
ConnectQuery query) → Future< Map< String, Object?> > -
exportJson(
ConnectQuery query) → Future< List> -
getSchema(
) → Future< List< CollectionSchema> > -
importJson(
String instance, String collection, List objects) → Future< void> -
listInstances(
) → Future< List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeQuery(
ConnectQuery query) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
watchInstance(
String instance) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
connect(
String port, String secret) → Future< ConnectClient>
Constants
- kLongTimeout → const Duration
- kNormalTimeout → const Duration